@@ -2,37 +2,12 @@
 # create an html dependency for Magnific popup
 html_dependency_magnific_popup <- function() {
   htmltools::htmlDependency(name = "magnific-popup",
-                            version = "0.9.9",
-                            src = system.file("templates/magnific-popup-0.9.9", package = "rmdformats"),
+                            version = "1.1.0",
+                            src = system.file("templates/magnific-popup-1.1.0", package = "rmdformats"),
                             script = "jquery.magnific-popup.min.js",
                             stylesheet = "magnific-popup.css")
 }
 
-
-# create an html dependency for jquery-ui
-html_dependency_jquery_ui <- function() {
-  htmltools::htmlDependency(name = "jquery-ui",
-                            version = "1.10.4",
-                            src = system.file("templates/jquery-ui-1.10.4", package = "rmdformats"),
-                            script = "jquery-ui-1.10.4.custom.min.js")
-}
-
-# create an html dependency for tocify
-html_dependency_tocify <- function() {
-  htmltools::htmlDependency(name = "tocify",
-                            version = "1.9.0",
-                            src = system.file("templates/tocify-1.9.0", package = "rmdformats"),
-                            script = "jquery.tocify.min.js")
-}
-
-# create an html dependency for embedded jquery (function copied from rmarkdown)
-html_dependency_jquery <- function()  {
-  htmltools::htmlDependency(name = "jquery",
-                 version = "1.11.0",
-                 src = system.file("templates/jquery-1.11.0", package = "rmdformats"),
-                 script = "jquery.min.js")
-}
-
 # create an html dependency for jquery-stickytableheaders
 html_dependency_jquery_stickytableheaders <- function()  {
   htmltools::htmlDependency(name = "jquery-stickytableheaders",
@@ -72,4 +47,3 @@ html_dependency_bootstrap_js <- function() {
 default_mathjax <- function() {
   "https://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML"
 }
-
